@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ContentHandler.cpp,v 1.60.4.2 2004/10/10 16:18:26 marco Exp $
+ *  $Id: ContentHandler.cpp,v 1.60.4.4 2004/11/14 11:40:01 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -207,30 +207,6 @@ NS_METHOD GContentHandler::LaunchHelperApp (void)
 	return NS_OK;
 }
 
-NS_METHOD GContentHandler::CheckAppSupportScheme (void)
-{
-	GList *l;
-
-	mAppSupportScheme = PR_FALSE;	
-
-	if (!mHelperApp) return NS_OK;
-
-	if (mHelperApp->expects_uris != GNOME_VFS_MIME_APPLICATION_ARGUMENT_TYPE_URIS)
-		return NS_OK;
-	
-	for (l = mHelperApp->supported_uri_schemes; l != NULL; l = l->next)
-	{
-		char *uri_scheme = (char *)l->data;
-
-		if (strcmp (mScheme.get(), uri_scheme) == 0)
-		{
-			mAppSupportScheme = PR_TRUE;
-		}
-	}
-
-	return NS_OK;
-}
-
 NS_METHOD GContentHandler::Init (void)
 {
 	nsresult rv;
@@ -367,8 +343,6 @@ NS_METHOD GContentHandler::MIMEDoAction (void)
 	mPermission = ephy_embed_shell_check_mime (embed_shell, mMimeType);
 #endif
 
-	CheckAppSupportScheme ();
-
 	if (auto_downloads)
 	{
 		mAction = CONTENT_ACTION_OPEN;
@@ -419,25 +393,11 @@ NS_METHOD GContentHandler::MIMEDoAction (void)
 
 	if (mAction == CONTENT_ACTION_OPEN)
 	{
-		if (mAppSupportScheme)
-		{
-			LaunchHelperApp ();
-		}
-		else
-		{
-			mLauncher->SaveToDisk (nsnull, PR_FALSE);
-		}
+		mLauncher->SaveToDisk (nsnull, PR_FALSE);
 	}
 	else if (mAction == CONTENT_ACTION_OPEN_TMP)
 	{
-		if (mAppSupportScheme)
-		{
-			LaunchHelperApp ();
-		}
-		else
-		{
-			mLauncher->LaunchWithApplication (nsnull, PR_FALSE);
-		}
+		mLauncher->LaunchWithApplication (nsnull, PR_FALSE);
 	}
 	else if (mAction == CONTENT_ACTION_NONE)
 	{
