@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ContentHandler.h,v 1.19.8.1 2004/09/21 11:13:21 chpe Exp $
+ *  $Id: ContentHandler.h,v 1.19.8.3 2004/11/14 11:40:01 chpe Exp $
  */
 
 #ifndef __ContentHandler_h
@@ -33,7 +33,9 @@
 #include <nsISupports.h>
 #include <nsIURI.h>
 #include <nsIFile.h>
+#define MOZILLA_STRICT_API
 #include <nsEmbedString.h>
+#undef MOZILLA_STRICT_API
 #include <nsIHelperAppLauncherDialog.h>
 
 typedef enum
@@ -69,7 +71,6 @@ class GContentHandler : public nsIHelperAppLauncherDialog
 
 	NS_METHOD MIMEConfirmAction ();
 	NS_METHOD MIMEDoAction ();
-	NS_METHOD CheckAppSupportScheme ();
 
 	nsCOMPtr<nsIHelperAppLauncher> mLauncher;
 	nsCOMPtr<nsIURI> mUri;
