@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyBrowser.cpp,v 1.53.4.4 2004/10/10 16:18:26 marco Exp $
+ *  $Id: EphyBrowser.cpp,v 1.53.4.7 2004/11/13 19:56:49 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -59,16 +59,24 @@
 #include "nsIDOMDocument.h"
 #include "nsIDOM3Document.h"
 #include "nsIDOMEvent.h"
+#include "nsIDOMNSEvent.h"
 #include "nsIDOMEventTarget.h"
 #include "nsIDOMPopupBlockedEvent.h"
 #include "nsIDOMNode.h"
 #include "nsIDOMElement.h"
 #include "nsIDOMWindow2.h"
+#define MOZILLA_STRICT_API
 #include "nsEmbedString.h"
+#undef MOZILLA_STRICT_API
 #include "nsMemory.h"
 #include "nsIChannel.h"
+#include "nsIScriptSecurityManager.h"
+#include "nsIServiceManager.h"
 
 #ifdef ALLOW_PRIVATE_API
+/* not frozen yet */
+#include "nsIContentPolicy.h"
+/* will never be frozen */
 #include "nsIDocShell.h"
 #include "nsIMarkupDocumentViewer.h"
 #ifdef HAVE_MOZILLA_PSM
@@ -82,6 +90,13 @@ static PRUnichar DOMLinkAdded[] = { 'D', 'O', 'M', 'L', 'i', 'n', 'k',
 static PRUnichar DOMPopupBlocked[] = { 'D', 'O', 'M', 'P', 'o', 'p',
 				       'u', 'p', 'B', 'l', 'o', 'c',
 				       'k', 'e', 'd', '\0' };
+static PRUnichar DOMWillOpenModalDialog[] = { 'D', 'O', 'M', 'W', 'i', 'l', 'l',
+					      'O', 'p', 'e', 'n', 'M', 'o', 'd',
+					      'a', 'l', 'D', 'i', 'a', 'l', 'o',
+					      'g', '\0' };
+static PRUnichar DOMModalDialogClosed[] = { 'D', 'O', 'M', 'M', 'o', 'd', 'a',
+					    'l', 'D', 'i', 'a', 'l', 'o', 'g',
+					    'C', 'l', 'o', 's', 'e', 'd', '\0' };
 
 EphyEventListener::EphyEventListener(void)
 : mOwner(nsnull)
@@ -103,9 +118,15 @@ EphyEventListener::Init(EphyEmbed *aOwner)
 	return NS_OK;
 }
 
-nsresult
-EphyFaviconEventListener::HandleFaviconLink (nsIDOMNode *node)
+NS_IMETHODIMP
+EphyFaviconEventListener::HandleEvent(nsIDOMEvent* aDOMEvent)
 {
+	nsCOMPtr<nsIDOMEventTarget> eventTarget;
+	aDOMEvent->GetTarget(getter_AddRefs(eventTarget));
+
+	nsCOMPtr<nsIDOMNode> node = do_QueryInterface(eventTarget);
+	NS_ENSURE_TRUE (node, NS_ERROR_FAILURE);
+
 	nsCOMPtr<nsIDOMElement> linkElement;
 	linkElement = do_QueryInterface (node);
 	if (!linkElement) return NS_ERROR_FAILURE;
@@ -139,35 +160,71 @@ EphyFaviconEventListener::HandleFaviconLink (nsIDOMNode *node)
 
 		nsEmbedString spec;
 		rv = doc->GetDocumentURI (spec);
-		NS_ENSURE_SUCCESS (rv, rv);
+		NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
-		nsCOMPtr<nsIURI> uri;
-		rv = EphyUtils::NewURI (getter_AddRefs(uri), spec);
-		NS_ENSURE_SUCCESS (rv, rv);
+		nsCOMPtr<nsIURI> docUri;
+		EphyUtils::NewURI (getter_AddRefs(docUri), spec);
+		NS_ENSURE_TRUE (docUri, NS_ERROR_FAILURE);
 
-		nsEmbedCString favicon_url;
-		rv = uri->Resolve (link, favicon_url);
-		if (NS_FAILED (rv)) return NS_ERROR_FAILURE;
-		
-		char *url = g_strdup (favicon_url.get());
+		nsEmbedCString faviconUrl;
+		rv = docUri->Resolve (link, faviconUrl);
+		NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
+
+		nsCOMPtr<nsIURI> favUri;
+		 EphyUtils::NewURI (getter_AddRefs (favUri), faviconUrl);
+		NS_ENSURE_TRUE (favUri, NS_ERROR_FAILURE);
+
+		/* check if load is allowed */
+		nsCOMPtr<nsIScriptSecurityManager> secMan
+			(do_GetService("@mozilla.org/scriptsecuritymanager;1"));
+		/* refuse if we can't check */
+		NS_ENSURE_TRUE (secMan, NS_OK);
+
+		rv = secMan->CheckLoadURI(docUri, favUri,
+					  nsIScriptSecurityManager::STANDARD);
+		/* failure means it didn't pass the security check */
+		if (NS_FAILED (rv)) return NS_OK;
+
+		/* security check passed, now check with content policy */
+		nsCOMPtr<nsIContentPolicy> policy =
+			do_GetService("@mozilla.org/layout/content-policy;1");
+		/* refuse if we can't check */
+		NS_ENSURE_TRUE (policy, NS_OK);
+
+#if MOZ_NSICONTENTPOLICY_VARIANT == 2
+		/* FIXME: mozilla tabbrowser.xml passes
+		 * safeGetProperty(event.target, "type") as mimetype guess:
+		 */
+		PRUnichar typeAttr[] = { 't', 'y', 'p', 'e', '\0' };
+		nsEmbedString typeVal;
+		linkElement->GetAttribute (nsEmbedString (typeAttr), typeVal);
+
+		nsEmbedCString cTypeVal;
+		NS_UTF16ToCString (typeVal, NS_CSTRING_ENCODING_UTF8, cTypeVal);
+
+		PRInt16 decision = 0;
+		rv = policy->ShouldLoad (nsIContentPolicy::TYPE_IMAGE,
+					 favUri, docUri, eventTarget,
+					 cTypeVal, nsnull,
+					 &decision);
+		NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
+		if (decision != nsIContentPolicy::ACCEPT) return NS_OK;
+#else
+		PRBool shouldLoad = PR_FALSE;
+		rv = policy->ShouldLoad (nsIContentPolicy::IMAGE,
+					 favUri, eventTarget,
+					 nsnull /* FIXME: DOM window*/,
+					 &shouldLoad);
+		NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
+		if (!shouldLoad) return NS_OK;
+#endif
+
+		/* ok, we accept this as a valid favicon for this site */
+		char *url = g_strdup (faviconUrl.get());
 		g_signal_emit_by_name (mOwner, "ge_favicon", url);
 		g_free (url);
 	}
 
-	return NS_OK;
-}	
-
-NS_IMETHODIMP
-EphyFaviconEventListener::HandleEvent(nsIDOMEvent* aDOMEvent)
-{
-	nsCOMPtr<nsIDOMEventTarget> eventTarget;
-	aDOMEvent->GetTarget(getter_AddRefs(eventTarget));
-
-	nsCOMPtr<nsIDOMNode> node = do_QueryInterface(eventTarget);
-	NS_ENSURE_TRUE (node, NS_ERROR_FAILURE);
-
-	HandleFaviconLink (node);
-
 	return NS_OK;
 }
 
@@ -205,9 +262,54 @@ EphyPopupBlockEventListener::HandleEvent (nsIDOMEvent * aDOMEvent)
 	return NS_OK;
 }
 
+NS_IMETHODIMP
+EphyModalAlertEventListener::HandleEvent (nsIDOMEvent * aDOMEvent)
+{
+#ifdef MOZ_NSIDOMNSEVENT_GETISTRUSTED
+	NS_ENSURE_TRUE (mOwner, NS_ERROR_FAILURE);
+
+	/* make sure the event is trusted */
+	nsCOMPtr<nsIDOMNSEvent> nsEvent (do_QueryInterface (aDOMEvent));
+	NS_ENSURE_TRUE (nsEvent, NS_ERROR_FAILURE);
+	PRBool isTrusted = PR_FALSE;
+	nsEvent->GetIsTrusted (&isTrusted);
+	if (!isTrusted) return NS_OK;
+
+	nsresult rv;
+	nsEmbedString type;
+	rv = aDOMEvent->GetType (type);
+	NS_ENSURE_SUCCESS (rv, rv);
+
+	nsEmbedCString cType;
+	NS_UTF16ToCString (type, NS_CSTRING_ENCODING_UTF8, cType);
+
+	LOG ("ModalAlertListener event %s", cType.get());
+
+	if (strcmp (cType.get(), "DOMWillOpenModalDialog") == 0)
+	{
+		gboolean retval = FALSE;
+		g_signal_emit_by_name (mOwner, "ge-modal-alert", &retval);
+
+		/* suppress alert */
+		if (retval)
+		{
+			aDOMEvent->PreventDefault ();
+			aDOMEvent->StopPropagation ();
+		}
+	}
+	else if (strcmp (cType.get(), "DOMModalDialogClosed") == 0)
+	{
+		g_signal_emit_by_name (mOwner, "ge-modal-alert-closed");
+	}
+#endif
+
+	return NS_OK;
+}
+
 EphyBrowser::EphyBrowser ()
 : mFaviconEventListener(nsnull)
 , mPopupBlockEventListener(nsnull)
+, mModalAlertListener(nsnull)
 , mInitialized(PR_FALSE)
 {
 	LOG ("EphyBrowser ctor (%p)", this)
@@ -247,6 +349,12 @@ nsresult EphyBrowser::Init (GtkMozEmbed *mozembed)
 	rv = mPopupBlockEventListener->Init (EPHY_EMBED (mozembed));
 	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
+	mModalAlertListener = new EphyModalAlertEventListener ();
+	if (!mModalAlertListener) return NS_ERROR_OUT_OF_MEMORY;
+
+	rv = mModalAlertListener->Init (EPHY_EMBED (mozembed));
+	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
+
  	rv = GetListener();
 	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
@@ -282,6 +390,10 @@ EphyBrowser::AttachListeners(void)
 					    mFaviconEventListener, PR_FALSE);
 	rv |= mEventTarget->AddEventListener(nsEmbedString(DOMPopupBlocked),
 					     mPopupBlockEventListener, PR_FALSE);
+	rv |= mEventTarget->AddEventListener(nsEmbedString(DOMWillOpenModalDialog),
+					     mModalAlertListener, PR_TRUE);
+	rv |= mEventTarget->AddEventListener(nsEmbedString(DOMModalDialogClosed),
+					     mModalAlertListener, PR_TRUE);
 	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
 	return NS_OK;
@@ -297,6 +409,10 @@ EphyBrowser::DetachListeners(void)
 					       mFaviconEventListener, PR_FALSE);
 	rv |= mEventTarget->RemoveEventListener(nsEmbedString(DOMPopupBlocked),
 					        mPopupBlockEventListener, PR_FALSE);
+	rv |= mEventTarget->RemoveEventListener(nsEmbedString(DOMWillOpenModalDialog),
+						mModalAlertListener, PR_TRUE);
+	rv |= mEventTarget->RemoveEventListener(nsEmbedString(DOMModalDialogClosed),
+						mModalAlertListener, PR_TRUE);
 	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
 	return NS_OK;
