@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyBrowser.h,v 1.25 2004/08/08 18:11:56 chpe Exp $
+ *  $Id: EphyBrowser.h,v 1.25.4.3 2004/10/30 17:49:42 chpe Exp $
  */
 
 #ifndef EPHY_BROWSER_H
@@ -25,8 +25,6 @@
 #include "config.h"
 #endif
 
-#include "mozilla-version.h"
-
 #include "ephy-encodings.h"
 #include "ephy-embed.h"
 
@@ -68,9 +66,6 @@ class EphyFaviconEventListener : public EphyEventListener
 {
 public:
 	NS_IMETHOD HandleEvent(nsIDOMEvent* aEvent);
-
-private:
-	nsresult HandleFaviconLink (nsIDOMNode *node);
 };
 
 class EphyPopupBlockEventListener : public EphyEventListener
@@ -79,6 +74,12 @@ public:
 	NS_IMETHOD HandleEvent(nsIDOMEvent* aEvent);
 };
 
+class EphyModalAlertEventListener : public EphyEventListener
+{
+public:
+	NS_IMETHOD HandleEvent(nsIDOMEvent* aEvent);
+};
+
 class EphyBrowser
 {
 public:
@@ -112,7 +113,7 @@ public:
 	nsresult GetSHUrlAtIndex (PRInt32 index, nsACString &url);
 	nsresult GoToHistoryIndex (PRInt16 index);
 
-#if (!MOZILLA_IS_BRANCH (1, 7) || !MOZILLA_CHECK_VERSION3 (1, 7, 3)) && !MOZILLA_CHECK_VERSION4 (1, 8, MOZILLA_ALPHA, 3)
+#ifdef GTKMOZEMBED_BROKEN_RELOAD
 	enum ReloadType { RELOAD_NORMAL		 = 0,
 			  RELOAD_FORCE		 = 1,
 			  RELOAD_ENCODING_CHANGE = 2 };
@@ -147,6 +148,7 @@ private:
 	nsCOMPtr<nsISupports> mSecurityInfo;
 	EphyFaviconEventListener *mFaviconEventListener;
 	EphyPopupBlockEventListener *mPopupBlockEventListener;
+	EphyModalAlertEventListener *mModalAlertListener;
 	PRBool mInitialized;
 
 	nsresult GetListener (void);
