@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphySingle.cpp,v 1.16 2004/08/08 11:54:11 chpe Exp $
+ *  $Id: EphySingle.cpp,v 1.17.4.1 2004/11/13 19:56:49 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -29,7 +29,9 @@
 
 #include "ephy-debug.h"
 
+#define MOZILLA_STRICT_API
 #include <nsEmbedString.h>
+#undef MOZILLA_STRICT_API
 #include <nsIURI.h>
 #include <nsIPermissionManager.h>
 #include <nsICookieManager.h>
@@ -60,6 +62,7 @@ EphySingle::Init (EphyEmbedSingle *aOwner)
 	rv |= mObserverService->AddObserver (this, "cookie-rejected", PR_FALSE);
 	rv |= mObserverService->AddObserver (this, "perm-changed", PR_FALSE);
 	rv |= mObserverService->AddObserver (this, "network:offline-status-changed", PR_FALSE);
+	rv |= mObserverService->AddObserver (this, "signonChanged", PR_FALSE);
 	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
 	mOwner = aOwner;
@@ -79,6 +82,7 @@ EphySingle::Detach ()
 		mObserverService->RemoveObserver (this, "cookie-changed");
 		mObserverService->RemoveObserver (this, "cookie-rejected");
 		mObserverService->RemoveObserver (this, "perm-changed");
+		mObserverService->RemoveObserver (this, "signonChanged");
 		mObserverService->RemoveObserver (this, "network:offline-status-changed");
 	}
 
@@ -215,6 +219,14 @@ NS_IMETHODIMP EphySingle::Observe(nsISupports *aSubject,
 			rv = NS_ERROR_FAILURE;
 		}
 	}
+	else if (strcmp (aTopic, "signonChanged") == 0)
+	{
+		/* aData can be PRUnichar[] "signons", "rejects", "nocaptures" and "nopreviews" */
+		if (aData[0] == 's')
+		{
+			g_signal_emit_by_name (mOwner, "passwords-changed");
+		}
+	}
 	else if (strcmp (aTopic, "network:offline-status-changed") == 0)
 	{
 		/* aData is either (PRUnichar[]) "offline" or "online" */
