@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: FilePicker.cpp,v 1.42.4.1 2004/09/21 11:13:21 chpe Exp $
+ *  $Id: FilePicker.cpp,v 1.42.4.3 2004/11/13 19:56:49 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -26,10 +26,12 @@
 #endif
 
 #include "FilePicker.h"
-#include "MozillaPrivate.h"
+#include "EphyUtils.h"
 
 #include <nsCOMPtr.h>
+#define MOZILLA_STRICT_API
 #include <nsEmbedString.h>
+#undef MOZILLA_STRICT_API
 #include <nsIServiceManager.h>
 #include <nsIURI.h>
 #include <nsIFileURL.h>
@@ -82,7 +84,7 @@ NS_IMETHODIMP GFilePicker::Init(nsIDOMWindowInternal *parent, const PRUnichar *t
 {
 	LOG ("GFilePicker::Init")
 
-	GtkWidget *gtkparent = MozillaFindGtkParent (parent);
+	GtkWidget *gtkparent = EphyUtils::FindGtkParent (parent);
 #if defined(MOZ_NSIFILEPICKER_NSASTRING_)
 	NS_ENSURE_TRUE (gtkparent, NS_ERROR_FAILURE);
 #endif
