@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: GtkNSSKeyPairDialogs.cpp,v 1.13.4.2 2004/10/10 16:18:26 marco Exp $
+ *  $Id: GtkNSSKeyPairDialogs.cpp,v 1.13.4.3 2004/11/13 21:27:25 chpe Exp $
  */
 
 /*
@@ -55,16 +55,15 @@
 #include "nsIDOMWindowInternal.h"
 #endif
 
-#include "gtk/gtkdialog.h"
-#include "gtk/gtkprogressbar.h"
-#include "gtk/gtkimage.h"
-#include "gtk/gtkstock.h"
-#include "gtk/gtklabel.h"
-#include "gtk/gtkhbox.h"
-#include "gtk/gtkvbox.h"
-#include "gtk/gtkmain.h"
-
-#include <libgnome/gnome-i18n.h>
+#include <gtk/gtkdialog.h>
+#include <gtk/gtkprogressbar.h>
+#include <gtk/gtkimage.h>
+#include <gtk/gtkstock.h>
+#include <gtk/gtklabel.h>
+#include <gtk/gtkhbox.h>
+#include <gtk/gtkvbox.h>
+#include <gtk/gtkmain.h>
+#include <glib/gi18n.h>
 
 #include "GtkNSSKeyPairDialogs.h"
 #include "ephy-debug.h"
