@@ -38,7 +38,7 @@
  *
  * ***** END LICENSE BLOCK *****
  *
- * $Id: MozDownload.cpp,v 1.47.4.3 2004/10/02 14:23:18 chpe Exp $
+ * $Id: MozDownload.cpp,v 1.47.4.4 2004/11/13 19:56:49 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -59,7 +59,9 @@
 #include <glib/gi18n.h>
 
 #include <nsIFileURL.h>
+#define MOZILLA_STRICT_API
 #include <nsEmbedString.h>
+#undef MOZILLA_STRICT_API
 
 const char* const persistContractID = "@mozilla.org/embedding/browser/nsWebBrowserPersist;1";
 
