@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-embed-single.cpp,v 1.92.4.2 2004/09/25 13:23:48 chpe Exp $
+ *  $Id: mozilla-embed-single.cpp,v 1.92.4.6 2004/11/13 19:56:49 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -51,7 +51,9 @@
 
 #include <nsCOMPtr.h>
 #include <nsMemory.h>
+#define MOZILLA_STRICT_API
 #include <nsEmbedString.h>
+#undef MOZILLA_STRICT_API
 #include <nsIPrefService.h>
 #include <nsIServiceManager.h>
 #include <nsIWindowWatcher.h>
@@ -320,6 +322,23 @@ mozilla_embed_single_new_window_orphan_cb (GtkMozEmbedSingle *embed,
 	*retval = _mozilla_embed_new_xul_dialog ();
 }
 
+static void
+mozilla_init_plugin_path ()
+{
+	const char *user_path;
+	char *new_path;
+
+	user_path = g_getenv ("MOZ_PLUGIN_PATH");
+	new_path = g_strconcat (user_path ? user_path : "",
+				user_path ? ":" : "",
+				MOZILLA_PREFIX "/lib/mozilla/plugins:"
+				MOZILLA_HOME "/plugins",
+				NULL);
+
+	g_setenv ("MOZ_PLUGIN_PATH", new_path, TRUE);
+	g_free (new_path);
+}
+
 static void
 mozilla_init_single (MozillaEmbedSingle *mes)
 {	
@@ -461,6 +480,7 @@ static gboolean
 init_services (MozillaEmbedSingle *single)
 {
 	/* Pre initialization */
+	mozilla_init_plugin_path ();
 	mozilla_init_home ();
 	mozilla_init_profile ();
 
@@ -542,6 +562,8 @@ mozilla_embed_single_dispose (GObject *object)
 		NS_RELEASE (single->priv->mSingleObserver);
 		single->priv->mSingleObserver = nsnull;
 	}
+
+	parent_class->dispose (object);
 }
 
 static void
@@ -609,6 +631,12 @@ impl_get_offline_mode (EphyEmbedSingle *shell)
 	return isOffline;
 }
 
+static GList *
+impl_get_printer_list (EphyEmbedSingle *shell)
+{
+	return MozillaPrivate::GetPrinterList ();
+}
+
 static GList *
 impl_get_font_list (EphyEmbedSingle *shell,
 		    const char *langGroup)
@@ -941,7 +969,7 @@ impl_open_window (EphyEmbedSingle *single,
 	wWatch->OpenWindow (domWindow, address, name, features, nsnull,
 			    getter_AddRefs (newWindow));
 
-	return MozillaFindEmbed (newWindow);
+	return EphyUtils::FindEmbed (newWindow);
 }
 
 static void
@@ -966,6 +994,7 @@ ephy_embed_single_iface_init (EphyEmbedSingleIface *iface)
 	iface->get_offline_mode = impl_get_offline_mode;
 	iface->get_font_list = impl_get_font_list;
 	iface->open_window = impl_open_window;
+	iface->get_printer_list = impl_get_printer_list;
 }
 
 static void
