@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-embed.cpp,v 1.83.4.2 2004/09/21 11:13:21 chpe Exp $
+ *  $Id: mozilla-embed.cpp,v 1.83.4.4 2004/11/13 19:56:49 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -32,13 +32,14 @@
 #include "ephy-string.h"
 #include "ephy-debug.h"
 
-#include "MozillaPrivate.h"
 #include "EphyBrowser.h"
 #include "EventContext.h"
 #include "EphyUtils.h"
 
 #include <gtkmozembed.h>
+#define MOZILLA_STRICT_API
 #include <nsEmbedString.h>
+#undef MOZILLA_STRICT_API
 #include <nsMemory.h>
 #include <nsIURI.h>
 #include <nsIRequest.h>
