@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-bookmark-properties.h,v 1.4 2003/11/19 19:19:59 chpe Exp $
+ *  $Id: ephy-bookmark-properties.h,v 1.4.16.1 2004/11/01 14:08:33 chpe Exp $
  */
 
 #ifndef EPHY_BOOKMARK_PROPERTIES_H
@@ -53,7 +53,7 @@ GType		     ephy_bookmark_properties_get_type        (void);
 
 GtkWidget	    *ephy_bookmark_properties_new             (EphyBookmarks *bookmarks,
 							       EphyNode *bookmark,
-							       GtkWindow *parent_window);
+							       GtkWidget *parent_window);
 
 EphyNode            *ephy_bookmark_properties_get_node        (EphyBookmarkProperties *properties);
 
