@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-notebook.c,v 1.46.4.2 2004/09/13 10:49:22 chpe Exp $
+ *  $Id: ephy-notebook.c,v 1.46.4.3 2004/10/31 19:42:45 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -1001,23 +1001,12 @@ void
 ephy_notebook_remove_tab (EphyNotebook *nb,
 			  EphyTab *tab)
 {
-	int num, position, curr;
+	int position, curr;
 	GtkWidget *label, *ebox;
 
 	g_return_if_fail (EPHY_IS_NOTEBOOK (nb));
 	g_return_if_fail (EPHY_IS_TAB (tab));
 
-	num = gtk_notebook_get_n_pages (GTK_NOTEBOOK (nb));
-	if (num <= 1)
-	{
-		GtkWidget *window;
-		window = gtk_widget_get_toplevel (GTK_WIDGET (nb));
-
-		g_signal_emit (G_OBJECT (nb), signals[TAB_REMOVED], 0, tab);
-		gtk_widget_destroy (window);
-		return;
-	}
-
 	/* Remove the page from the focused pages list */
 	nb->priv->focused_pages =  g_list_remove (nb->priv->focused_pages,
 						  tab);
@@ -1054,4 +1043,10 @@ ephy_notebook_remove_tab (EphyNotebook *nb,
 	g_signal_emit (G_OBJECT (nb), signals[TAB_REMOVED], 0, tab);
 
 	g_object_unref (tab);
+
+	/* if that was the last tab, destroy the window */
+	if (gtk_notebook_get_n_pages (GTK_NOTEBOOK (nb)) == 0)
+	{
+		gtk_widget_destroy (gtk_widget_get_toplevel (GTK_WIDGET (nb)));
+	}
 }
