@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-shell.c,v 1.90 2004/08/06 14:34:07 chpe Exp $
+ *  $Id: ephy-shell.c,v 1.91.4.2 2004/10/16 13:52:16 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -263,7 +263,7 @@ save_yourself_cb (GnomeClient *client,
 		  EphyShell *shell)
 {
 	char *argv[] = { "epiphany", "--load-session", NULL };
-	char *discard_argv[] = { "rm", "-r", NULL };
+	char *discard_argv[] = { "rm", "-f", NULL };
 	EphySession *session;
 	char *tmp, *save_to;
 
@@ -653,6 +653,8 @@ ephy_shell_get_bookmarks (EphyShell *shell)
 GObject *
 ephy_shell_get_toolbars_model (EphyShell *shell, gboolean fullscreen)
 {
+	LOG ("ephy_shell_get_toolbars_model fs=%d", fullscreen)
+
 	if (fullscreen)
 	{
 		if (shell->priv->fs_toolbars_model == NULL)
@@ -676,7 +678,7 @@ ephy_shell_get_toolbars_model (EphyShell *shell, gboolean fullscreen)
 		if (shell->priv->toolbars_model == NULL)
 		{
 			EphyBookmarks *bookmarks;
-			EggToolbarsModel *bookmarksbar_model;
+			GObject *bookmarksbar_model;
 
 			shell->priv->toolbars_model = ephy_toolbars_model_new ();
 
@@ -689,7 +691,7 @@ ephy_shell_get_toolbars_model (EphyShell *shell, gboolean fullscreen)
 
 			/* ok, now we can load the model */
 			ephy_toolbars_model_load
-			(EPHY_TOOLBARS_MODEL (shell->priv->toolbars_model));
+				(EPHY_TOOLBARS_MODEL (shell->priv->toolbars_model));
 		}
 
 		return G_OBJECT (shell->priv->toolbars_model);
