@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: window-commands.c,v 1.131.4.2 2004/10/04 22:03:23 chpe Exp $
+ *  $Id: window-commands.c,v 1.131.4.3 2004/10/08 12:16:39 marco Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -53,6 +53,7 @@
 #include <libgnomevfs/gnome-vfs-uri.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <libgnomeui/gnome-stock-icons.h>
+#include <libgnomeui/gnome-about.h>
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
 #include <gtk/gtkeditable.h>
 #include <gtk/gtkmain.h>
@@ -907,9 +908,8 @@ window_cmd_edit_toolbar (GtkAction *action,
 	
 	g_signal_connect (G_OBJECT (dialog), "response",
 			  G_CALLBACK (toolbar_editor_response_cb), model);
-	ephy_state_add_window (dialog,
-			       "toolbar_editor",
-		               500, 330,
+	ephy_state_add_window (dialog, "toolbar_editor",
+		               500, 330, FALSE,
 			       EPHY_STATE_WINDOW_SAVE_SIZE);
 	gtk_widget_show (dialog);
 
